@@ -19,11 +19,14 @@ class WorkflowVersionModel(BaseModel):
     description: Mapped[Optional[str]] = mapped_column(String)
     definition: Mapped[Any] = mapped_column(JSON, nullable=False)
     definition_hash: Mapped[str] = mapped_column(String, nullable=False)
-    created_at: Mapped[datetime] = mapped_column(DateTime, default=datetime.now(timezone.utc))
+    created_at: Mapped[datetime] = mapped_column(
+        DateTime, default=datetime.now(timezone.utc), index=True
+    )
     updated_at: Mapped[datetime] = mapped_column(
         DateTime,
         default=datetime.now(timezone.utc),
         onupdate=datetime.now(timezone.utc),
+        index=True,
     )
 
     # Relationships
