@@ -1,5 +1,5 @@
-from typing import Dict, List, Optional
 import logging
+from typing import Optional
 
 from pydantic import BaseModel, create_model
 
@@ -7,6 +7,7 @@ from ..base import BaseNode, BaseNodeConfig, BaseNodeInput, BaseNodeOutput
 
 logger = logging.getLogger(__name__)
 
+
 class MergeNodeConfig(BaseNodeConfig):
     has_fixed_output: bool = False
 
@@ -23,9 +24,7 @@ class MergeNodeOutput(BaseNodeOutput):
 
 
 class MergeNode(BaseNode):
-    """
-    Merge node takes all its inputs and combines them into one output
-    """
+    """Takes all its inputs and merge them into one output."""
 
     name = "merge_node"
     display_name = "Merge"
@@ -33,17 +32,16 @@ class MergeNode(BaseNode):
     config_model = MergeNodeConfig
 
     async def run(self, input: BaseModel) -> BaseModel:
-
         data = input.model_dump()
 
         self.output_model = create_model(
             f"{self.name}",
-            **{
-                k: (Optional[type(v)], ...) for k, v in data.items()
-            },
+            **{k: (Optional[type(v)], ...) for k, v in data.items()},
             __base__=MergeNodeOutput,
             __module__=self.__module__,
             __doc__=f"Output model for {self.name} node",
+            __cls_kwargs__=None,
+            __config__=None,
+            __validators__=None,
         )
         return self.output_model(**data)
-
